@@ -836,8 +836,10 @@ class ClioTestCase(unittest.TestCase):
         one = self._get_published()
         editable = one.edit()
         published2 = editable.publish()
-        self.assertRaises(clio.RevertError, one.revert)
-
+        reverted = one.revert()
+        # reverting an archived version has no effect
+        self.assertEquals(reverted, one)
+        
     def test_a_rel_revert_new(self):
         one = self._get_rel_published()
         b3 = B(b_code(self.session), u"B3")
